striplog
========

.. image:: https://img.shields.io/travis/agile-geoscience/striplog.svg
    :target: https://travis-ci.org/agile-geoscience/striplog
    :alt: Travis build status
    
.. image:: https://img.shields.io/pypi/status/striplog.svg
    :target: https://pypi.python.org/pypi/striplog/
    :alt: Development status

.. image:: https://img.shields.io/pypi/v/striplog.svg
    :target: https://pypi.python.org/pypi/striplog/
    :alt: Latest version
    
.. image:: https://img.shields.io/pypi/pyversions/striplog.svg
    :target: https://pypi.python.org/pypi/striplog/
    :alt: Python version
    
.. image:: https://img.shields.io/coveralls/agile-geoscience/striplog.svg 
    :target: https://coveralls.io/r/agile-geoscience/striplog
    :alt: Coveralls coverage

.. image:: https://img.shields.io/codacy/ad9af103cba14d33abd5b327727ff644.svg 
    :target: https://www.codacy.com/app/matt/striplog/dashboard
    :alt: Codacy code review

.. image:: https://img.shields.io/pypi/l/striplog.svg
    :target: http://www.apache.org/licenses/LICENSE-2.0
    :alt: License

Lithology and stratigraphic logs for wells. 

Utilities for handling lithologic and stratigraphic 'interval' logs. Includes a version of `las.py` for loading LAS well log data. 

Docs
----

* `Read The Docs <https://striplog.readthedocs.org/>`_

Dependencies
------------

* `NumPy <http://www.numpy.org/>`_
* `Pillow <https://pillow.readthedocs.org/>`_
* `matplotlib <http://matplotlib.org/>`_

Install
-------

* ``pip install striplog``
